@@ -29,18 +29,6 @@
 </context>
 <context>
     <name>DailyProgress</name>
-    <message numerus="yes">
-        <source>%1% of %Ln minute(s)</source>
-        <translation>
-            <numerusform>%1% dari %Ln menit</numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>%1% of %Ln word(s)</source>
-        <translation>
-            <numerusform>%1% dari %Ln kata</numerusform>
-        </translation>
-    </message>
     <message numerus="yes">
         <source>%Ln word(s)</source>
         <translation>
@@ -57,6 +45,18 @@
         <source>0%</source>
         <translation>0%</translation>
     </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln minute(s)</source>
+        <translation>
+            <numerusform>%L1% dari %Ln menit</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln word(s)</source>
+        <translation>
+            <numerusform>%L1% dari %Ln kata</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>DailyProgressDialog</name>
@@ -90,8 +90,8 @@
 <context>
     <name>DailyProgressLabel</name>
     <message>
-        <source>%1% of daily goal</source>
-        <translation>%1% dari target harian</translation>
+        <source>%L1% of daily goal</source>
+        <translation>%L1% dari target harian</translation>
     </message>
 </context>
 <context>
@@ -281,10 +281,6 @@
         <source>OpenDocument Text</source>
         <translation>Teks OpenDocument</translation>
     </message>
-    <message>
-        <source>OpenDocument Flat XML</source>
-        <translation>Buka berkas XML</translation>
-    </message>
     <message>
         <source>Office Open XML</source>
         <translation>Office Open XML</translation>
@@ -305,6 +301,10 @@
         <source>All Supported Files</source>
         <translation>Semua File Yang Didukung</translation>
     </message>
+    <message>
+        <source>OpenDocument Flat XML</source>
+        <translation>Buka berkas XML</translation>
+    </message>
 </context>
 <context>
     <name>Highlighter</name>
@@ -328,8 +328,8 @@
         <translation>Buka Gambar</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Gambar(%1)</translation>
+        <source>Images</source>
+        <translation>Gambar</translation>
     </message>
 </context>
 <context>
@@ -508,10 +508,6 @@
         <source>Reset daily progress for today to zero?</source>
         <translation>Reset kemajuan harian hari ini ke nol?</translation>
     </message>
-    <message>
-        <source>Remove current dictionary?</source>
-        <translation>Hilangkan kamus ini?</translation>
-    </message>
     <message>
         <source>Write byte order mark in plain text files</source>
         <translation>Tulis byte order mark di file teks polos</translation>
@@ -520,22 +516,6 @@
         <source>Default format:</source>
         <translation>Format standar:</translation>
     </message>
-    <message>
-        <source>User Interface</source>
-        <translation>Tampilan pengguna</translation>
-    </message>
-    <message>
-        <source>Always show scrollbar</source>
-        <translation>Scrollbar selalu tampak</translation>
-    </message>
-    <message>
-        <source>Always show top bar</source>
-        <translation>Bilah atas selalu tampak</translation>
-    </message>
-    <message>
-        <source>Always show bottom bar</source>
-        <translation>Bilah bawah selalu tampak</translation>
-    </message>
     <message>
         <source>Reset Today</source>
         <translation>Reset Hari Ini</translation>
@@ -652,6 +632,26 @@
         <source>Personal Dictionary</source>
         <translation>Kamus Pribadi</translation>
     </message>
+    <message>
+        <source>Remove current dictionary?</source>
+        <translation>Hilangkan kamus ini?</translation>
+    </message>
+    <message>
+        <source>User Interface</source>
+        <translation>Tampilan pengguna</translation>
+    </message>
+    <message>
+        <source>Always show scrollbar</source>
+        <translation>Scrollbar selalu tampak</translation>
+    </message>
+    <message>
+        <source>Always show top bar</source>
+        <translation>Bilah atas selalu tampak</translation>
+    </message>
+    <message>
+        <source>Always show bottom bar</source>
+        <translation>Bilah bawah selalu tampak</translation>
+    </message>
 </context>
 <context>
     <name>RtfReader</name>
@@ -1107,14 +1107,6 @@
         <source>Default</source>
         <translation>Standar</translation>
     </message>
-    <message>
-        <source>Bitter Skies</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Enchantment</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Gentle Blues</source>
         <translation>Gentle Blues</translation>
@@ -1127,14 +1119,6 @@
         <source>Space Dreams</source>
         <translation>Space Dreams</translation>
     </message>
-    <message>
-        <source>Spy Games</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Tranquility</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Writing Desk</source>
         <translation>Nulis Meja</translation>
@@ -1187,6 +1171,22 @@
         <source>Export Theme</source>
         <translation>Ekspor Tema</translation>
     </message>
+    <message>
+        <source>Bitter Skies</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enchantment</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Spy Games</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tranquility</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Timer</name>
@@ -1491,10 +1491,6 @@
         <source>&amp;Print...</source>
         <translation>&amp;Cetak...</translation>
     </message>
-    <message>
-        <source>Pa&amp;ge Setup...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Close</source>
         <translation>&amp;Tutup</translation>
@@ -1555,38 +1551,6 @@
         <source>Fo&amp;rmat</source>
         <translation>Fo&amp;rmat</translation>
     </message>
-    <message>
-        <source>&amp;Heading</source>
-        <translation>&amp;Heading</translation>
-    </message>
-    <message>
-        <source>Heading &amp;1</source>
-        <translation>Heading &amp;1</translation>
-    </message>
-    <message>
-        <source>Heading &amp;2</source>
-        <translation>Heading &amp;2</translation>
-    </message>
-    <message>
-        <source>Heading &amp;3</source>
-        <translation>Heading &amp;3</translation>
-    </message>
-    <message>
-        <source>Heading &amp;4</source>
-        <translation>Heading &amp;4</translation>
-    </message>
-    <message>
-        <source>Heading &amp;5</source>
-        <translation>Heading &amp;5</translation>
-    </message>
-    <message>
-        <source>Heading &amp;6</source>
-        <translation>Heading &amp;6</translation>
-    </message>
-    <message>
-        <source>&amp;Normal</source>
-        <translation>&amp;Normal</translation>
-    </message>
     <message>
         <source>&amp;Bold</source>
         <translation>&amp;Tebal</translation>
@@ -1711,18 +1675,10 @@
         <source>Update &amp;Document</source>
         <translation>Perbarui &amp;Dokumen</translation>
     </message>
-    <message>
-        <source>Update Document Smart Quotes</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Update &amp;Selection</source>
         <translation>Perbarui &amp;Seleksi</translation>
     </message>
-    <message>
-        <source>Update Selection Smart Quotes</source>
-        <translation>Perbarui Pilhan Kutipan Cerdas</translation>
-    </message>
     <message>
         <source>&amp;Spelling...</source>
         <translation>%Ejaan...</translation>
@@ -1811,10 +1767,6 @@
         <source>Focus Paragraph</source>
         <translation>Fokus Paragraf</translation>
     </message>
-    <message>
-        <source>Ctrl+Shift+`</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Help</source>
         <translation>&amp;Bantuan</translation>
@@ -1847,5 +1799,60 @@
         <source>About &amp;Qt</source>
         <translation>Tentang &amp;Qt</translation>
     </message>
+    <message>
+        <source>Pa&amp;ge Setup...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Heading</source>
+        <translation>&amp;Heading</translation>
+    </message>
+    <message>
+        <source>Heading &amp;1</source>
+        <translation>Heading &amp;1</translation>
+    </message>
+    <message>
+        <source>Heading &amp;2</source>
+        <translation>Heading &amp;2</translation>
+    </message>
+    <message>
+        <source>Heading &amp;3</source>
+        <translation>Heading &amp;3</translation>
+    </message>
+    <message>
+        <source>Heading &amp;4</source>
+        <translation>Heading &amp;4</translation>
+    </message>
+    <message>
+        <source>Heading &amp;5</source>
+        <translation>Heading &amp;5</translation>
+    </message>
+    <message>
+        <source>Heading &amp;6</source>
+        <translation>Heading &amp;6</translation>
+    </message>
+    <message>
+        <source>&amp;Normal</source>
+        <translation>&amp;Normal</translation>
+    </message>
+    <message>
+        <source>Update Document Smart Quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Update Selection Smart Quotes</source>
+        <translation>Perbarui Pilhan Kutipan Cerdas</translation>
+    </message>
+    <message>
+        <source>Ctrl+Shift+`</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
