@@ -29,18 +29,6 @@
 </context>
 <context>
     <name>DailyProgress</name>
-    <message numerus="yes">
-        <source>%1% of %Ln minute(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>%1% of %Ln word(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-        </translation>
-    </message>
     <message numerus="yes">
         <source>%Ln word(s)</source>
         <translation>
@@ -57,6 +45,18 @@
         <source>0%</source>
         <translation>0%</translation>
     </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln minute(s)</source>
+        <translation>
+            <numerusform>%Ln dakikanın %L1% &apos;i</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln word(s)</source>
+        <translation>
+            <numerusform>%Ln dakikanın %L1%&apos;si</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>DailyProgressDialog</name>
@@ -90,8 +90,8 @@
 <context>
     <name>DailyProgressLabel</name>
     <message>
-        <source>%1% of daily goal</source>
-        <translation>Günlük hedeften % %1</translation>
+        <source>%L1% of daily goal</source>
+        <translation>Günlük hedeften % %L1</translation>
     </message>
 </context>
 <context>
@@ -281,10 +281,6 @@
         <source>OpenDocument Text</source>
         <translation>OpenDocument Metni</translation>
     </message>
-    <message>
-        <source>OpenDocument Flat XML</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Office Open XML</source>
         <translation>Ofis Açık XML</translation>
@@ -305,6 +301,10 @@
         <source>All Supported Files</source>
         <translation>Tüm Desteklenen Dosyalar</translation>
     </message>
+    <message>
+        <source>OpenDocument Flat XML</source>
+        <translation>OpenDocument Düz XML</translation>
+    </message>
 </context>
 <context>
     <name>Highlighter</name>
@@ -328,8 +328,8 @@
         <translation>Resim Aç</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Resimler(%1)</translation>
+        <source>Images</source>
+        <translation>Resimler</translation>
     </message>
 </context>
 <context>
@@ -508,34 +508,14 @@
         <source>Reset daily progress for today to zero?</source>
         <translation>Bugünkü ilerleme sıfırlansın mı?</translation>
     </message>
-    <message>
-        <source>Remove current dictionary?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Write byte order mark in plain text files</source>
-        <translation type="unfinished"></translation>
+        <translation>Düz metin dosyalarında bayt sırası işareti yaz</translation>
     </message>
     <message>
         <source>Default format:</source>
         <translation>Varsayılan biçim:</translation>
     </message>
-    <message>
-        <source>User Interface</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Always show scrollbar</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Always show top bar</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Always show bottom bar</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Reset Today</source>
         <translation>Bugünü Sıfırla</translation>
@@ -554,7 +534,7 @@
     </message>
     <message>
         <source>Minimum progress for streaks:</source>
-        <translation type="unfinished"></translation>
+        <translation>Çizgiler için asgari ilerleme:</translation>
     </message>
     <message>
         <source>Detect word boundaries</source>
@@ -652,6 +632,26 @@
         <source>Personal Dictionary</source>
         <translation>Kişisel Sözlük</translation>
     </message>
+    <message>
+        <source>Remove current dictionary?</source>
+        <translation>Mevcut sözlük kaldırılsın mı?</translation>
+    </message>
+    <message>
+        <source>User Interface</source>
+        <translation>Kullanıcı Arayüzü</translation>
+    </message>
+    <message>
+        <source>Always show scrollbar</source>
+        <translation>Her zaman kaydırma çubuğunu göster</translation>
+    </message>
+    <message>
+        <source>Always show top bar</source>
+        <translation>Her zaman üst çubuğu göster</translation>
+    </message>
+    <message>
+        <source>Always show bottom bar</source>
+        <translation>Her zaman alt çubuğu göster</translation>
+    </message>
 </context>
 <context>
     <name>RtfReader</name>
@@ -966,7 +966,7 @@
     </message>
     <message>
         <source>Round Text Background Corners</source>
-        <translation type="unfinished"></translation>
+        <translation>Yuvarlak Metin Arka Plan Köşeleri</translation>
     </message>
     <message>
         <source>Radius:</source>
@@ -974,11 +974,11 @@
     </message>
     <message>
         <source>Blur Text Background</source>
-        <translation type="unfinished"></translation>
+        <translation>Metinlerin Arkaplanını Bulanıklaştırma</translation>
     </message>
     <message>
         <source>Text Background Drop Shadow</source>
-        <translation type="unfinished"></translation>
+        <translation>Metin Arka Planı Alt Gölge</translation>
     </message>
     <message>
         <source>Vertical Offset:</source>
@@ -1002,11 +1002,11 @@
     </message>
     <message>
         <source>Above:</source>
-        <translation type="unfinished"></translation>
+        <translation>Altında:</translation>
     </message>
     <message>
         <source>Below:</source>
-        <translation type="unfinished"></translation>
+        <translation>Üstünde:</translation>
     </message>
     <message>
         <source>Remove</source>
@@ -1107,14 +1107,6 @@
         <source>Default</source>
         <translation>Varsayılan</translation>
     </message>
-    <message>
-        <source>Bitter Skies</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Enchantment</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Gentle Blues</source>
         <translation>Kibar Mavi</translation>
@@ -1127,14 +1119,6 @@
         <source>Space Dreams</source>
         <translation>Uzay Düşleri</translation>
     </message>
-    <message>
-        <source>Spy Games</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Tranquility</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Writing Desk</source>
         <translation>Yazı Masası</translation>
@@ -1187,6 +1171,22 @@
         <source>Export Theme</source>
         <translation>Temayı Ver</translation>
     </message>
+    <message>
+        <source>Bitter Skies</source>
+        <translation>İliklere İşleyen Gökler </translation>
+    </message>
+    <message>
+        <source>Enchantment</source>
+        <translation>Büyü</translation>
+    </message>
+    <message>
+        <source>Spy Games</source>
+        <translation>Ajan Oyunları</translation>
+    </message>
+    <message>
+        <source>Tranquility</source>
+        <translation>Sükunet</translation>
+    </message>
 </context>
 <context>
     <name>Timer</name>
@@ -1491,10 +1491,6 @@
         <source>&amp;Print...</source>
         <translation>Ya&amp;zdır...</translation>
     </message>
-    <message>
-        <source>Pa&amp;ge Setup...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Close</source>
         <translation>Ka&amp;pat</translation>
@@ -1555,38 +1551,6 @@
         <source>Fo&amp;rmat</source>
         <translation>&amp;Biçim</translation>
     </message>
-    <message>
-        <source>&amp;Heading</source>
-        <translation>Başlık</translation>
-    </message>
-    <message>
-        <source>Heading &amp;1</source>
-        <translation>Başlık &amp;1</translation>
-    </message>
-    <message>
-        <source>Heading &amp;2</source>
-        <translation>Başlık &amp;2</translation>
-    </message>
-    <message>
-        <source>Heading &amp;3</source>
-        <translation>Başlık &amp;3</translation>
-    </message>
-    <message>
-        <source>Heading &amp;4</source>
-        <translation>Başlık &amp;4</translation>
-    </message>
-    <message>
-        <source>Heading &amp;5</source>
-        <translation>Başlık &amp;5</translation>
-    </message>
-    <message>
-        <source>Heading &amp;6</source>
-        <translation>Başlık &amp;6</translation>
-    </message>
-    <message>
-        <source>&amp;Normal</source>
-        <translation>&amp;Normal</translation>
-    </message>
     <message>
         <source>&amp;Bold</source>
         <translation>&amp;Kalın</translation>
@@ -1711,18 +1675,10 @@
         <source>Update &amp;Document</source>
         <translation>&amp;Dökümanı Güncelle</translation>
     </message>
-    <message>
-        <source>Update Document Smart Quotes</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Update &amp;Selection</source>
         <translation>&amp;Seçilimi Güncelle</translation>
     </message>
-    <message>
-        <source>Update Selection Smart Quotes</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Spelling...</source>
         <translation>&amp;Yazım Denetimi...</translation>
@@ -1811,10 +1767,6 @@
         <source>Focus Paragraph</source>
         <translation>Paragrafa Odaklan</translation>
     </message>
-    <message>
-        <source>Ctrl+Shift+`</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Help</source>
         <translation>&amp;Yardım</translation>
@@ -1847,5 +1799,60 @@
         <source>About &amp;Qt</source>
         <translation>&amp;Qt Hakkında</translation>
     </message>
+    <message>
+        <source>Pa&amp;ge Setup...</source>
+        <translation>Say&amp;fa Ayarı...</translation>
+    </message>
+    <message>
+        <source>&amp;Heading</source>
+        <translation>Başlık</translation>
+    </message>
+    <message>
+        <source>Heading &amp;1</source>
+        <translation>Başlık &amp;1</translation>
+    </message>
+    <message>
+        <source>Heading &amp;2</source>
+        <translation>Başlık &amp;2</translation>
+    </message>
+    <message>
+        <source>Heading &amp;3</source>
+        <translation>Başlık &amp;3</translation>
+    </message>
+    <message>
+        <source>Heading &amp;4</source>
+        <translation>Başlık &amp;4</translation>
+    </message>
+    <message>
+        <source>Heading &amp;5</source>
+        <translation>Başlık &amp;5</translation>
+    </message>
+    <message>
+        <source>Heading &amp;6</source>
+        <translation>Başlık &amp;6</translation>
+    </message>
+    <message>
+        <source>&amp;Normal</source>
+        <translation>&amp;Normal</translation>
+    </message>
+    <message>
+        <source>Update Document Smart Quotes</source>
+        <translation>Belge Akıllı Alıntılarını Güncelle</translation>
+    </message>
+    <message>
+        <source>Update Selection Smart Quotes</source>
+        <translation>Akıllı Alıntılar Seçimini Güncelle </translation>
+    </message>
+    <message>
+        <source>Ctrl+Shift+`</source>
+        <translation>Ctrl+Shift+`</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation>Geçerli oturumda açılacak dosyalar.</translation>
+    </message>
 </context>
 </TS>
