@@ -29,18 +29,6 @@
 </context>
 <context>
     <name>DailyProgress</name>
-    <message numerus="yes">
-        <source>%1% of %Ln minute(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>%1% of %Ln word(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-        </translation>
-    </message>
     <message numerus="yes">
         <source>%Ln word(s)</source>
         <translation type="unfinished">
@@ -57,6 +45,18 @@
         <source>0%</source>
         <translation type="unfinished"></translation>
     </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln minute(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln word(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>DailyProgressDialog</name>
@@ -90,7 +90,7 @@
 <context>
     <name>DailyProgressLabel</name>
     <message>
-        <source>%1% of daily goal</source>
+        <source>%L1% of daily goal</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -281,10 +281,6 @@
         <source>OpenDocument Text</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>OpenDocument Flat XML</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Office Open XML</source>
         <translation type="unfinished"></translation>
@@ -305,6 +301,10 @@
         <source>All Supported Files</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>OpenDocument Flat XML</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Highlighter</name>
@@ -328,8 +328,8 @@
         <translation>Mở hình ảnh</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Hình ảnh(%1)</translation>
+        <source>Images</source>
+        <translation>Hình ảnh</translation>
     </message>
 </context>
 <context>
@@ -508,10 +508,6 @@
         <source>Reset daily progress for today to zero?</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Remove current dictionary?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Write byte order mark in plain text files</source>
         <translation type="unfinished"></translation>
@@ -520,22 +516,6 @@
         <source>Default format:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>User Interface</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Always show scrollbar</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Always show top bar</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Always show bottom bar</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Reset Today</source>
         <translation type="unfinished"></translation>
@@ -652,6 +632,26 @@
         <source>Personal Dictionary</source>
         <translation>Từ điển tự tạo</translation>
     </message>
+    <message>
+        <source>Remove current dictionary?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Interface</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always show scrollbar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always show top bar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always show bottom bar</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RtfReader</name>
@@ -1107,14 +1107,6 @@
         <source>Default</source>
         <translation type="unfinished">Mặc định</translation>
     </message>
-    <message>
-        <source>Bitter Skies</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Enchantment</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Gentle Blues</source>
         <translation type="unfinished"></translation>
@@ -1127,14 +1119,6 @@
         <source>Space Dreams</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Spy Games</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Tranquility</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Writing Desk</source>
         <translation type="unfinished"></translation>
@@ -1187,6 +1171,22 @@
         <source>Export Theme</source>
         <translation>Xuất dữ liệu về giao diện</translation>
     </message>
+    <message>
+        <source>Bitter Skies</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enchantment</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Spy Games</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tranquility</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Timer</name>
@@ -1491,10 +1491,6 @@
         <source>&amp;Print...</source>
         <translation>&amp;In dữ liệu...</translation>
     </message>
-    <message>
-        <source>Pa&amp;ge Setup...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Close</source>
         <translation>Đ&amp;óng lại</translation>
@@ -1555,38 +1551,6 @@
         <source>Fo&amp;rmat</source>
         <translation>Đị&amp;nh dạng</translation>
     </message>
-    <message>
-        <source>&amp;Heading</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Heading &amp;1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Heading &amp;2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Heading &amp;3</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Heading &amp;4</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Heading &amp;5</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Heading &amp;6</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Normal</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Bold</source>
         <translation>&amp;In đậm</translation>
@@ -1711,18 +1675,10 @@
         <source>Update &amp;Document</source>
         <translation>Cập nhật tà&amp;i liệu</translation>
     </message>
-    <message>
-        <source>Update Document Smart Quotes</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Update &amp;Selection</source>
         <translation>Cập nhật v&amp;ùng lựa chọn</translation>
     </message>
-    <message>
-        <source>Update Selection Smart Quotes</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Spelling...</source>
         <translation>Kiểm tr&amp;a lỗi chính tả...</translation>
@@ -1811,10 +1767,6 @@
         <source>Focus Paragraph</source>
         <translation>Tập trung vào đoạn văn</translation>
     </message>
-    <message>
-        <source>Ctrl+Shift+`</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Help</source>
         <translation>Dịch bởi P&amp;han Anh</translation>
@@ -1847,5 +1799,60 @@
         <source>About &amp;Qt</source>
         <translation>Thô&amp;ng tin về Qt</translation>
     </message>
+    <message>
+        <source>Pa&amp;ge Setup...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Heading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Heading &amp;1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Heading &amp;2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Heading &amp;3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Heading &amp;4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Heading &amp;5</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Heading &amp;6</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Normal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Update Document Smart Quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Update Selection Smart Quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+Shift+`</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
